@@ -356,4 +356,4 @@ class Remote(object):
 		proc = subprocess.run(f'git -C {str(self.repository.path)} rev-list --count {self.name}/{branch}..HEAD', shell=True, capture_output=True, text=True)
 		if proc.stdout is None:
 			return proc.stderr
-		return proc.stdout.strip()[0]
+		return proc.stdout.strip()
